## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Not all test dependencies are packaged for fedora
%bcond check 0

Name:    newsboat
Version: 2.38
Release: %{autorelease}
Summary: RSS/Atom feed reader for the text console

License: MIT
URL:     https://www.newsboat.org
Source0: https://newsboat.org/releases/%{version}/%{name}-%{version}.tar.xz
Source1: https://newsboat.org/releases/%{version}/%{name}-%{version}.tar.xz.asc
Source2: https://newsboat.org/newsboat.pgp

Patch:  0001-make-do-not-require-Cargo.lock.patch
Patch:  0002-libnewsboat-relax-requirements.patch
Patch:  0003-Do-not-build-http-test-server-by-default.patch
## # Following patches should be included in next release; prune when updating

# Source file verification
BuildRequires: make
BuildRequires: gnupg2

BuildRequires: asciidoctor
BuildRequires: gcc-c++
BuildRequires: gettext
BuildRequires: pkgconfig
BuildRequires: pkgconfig(json-c) >= 0.11
BuildRequires: pkgconfig(libcrypto)
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(ncursesw)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(stfl)
# Rust parts
BuildRequires:  git
BuildRequires:  rust-packaging

Provides: podboat = %{version}-%{release}

%description
Newsboat is a fork of Newsbeuter, an RSS/Atom feed reader for the text console.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
# Note to self: do not use -S git_am for released builds, it messes up version string
%autosetup -p1
%cargo_prep

%generate_buildrequires
INTERNAL_CRATES=$'libnewsboat\nlibnewsboat-ffi\nregex-rs\nstrprintf'
cargo2rpm --path=Cargo.toml buildrequires --all-features %{?with_check:--with-check}|grep -vwe "${INTERNAL_CRATES}"

%build
# Respect RPM settings
%set_build_flags
# Do not fail build because our GCC emits different warnings
export CFLAGS="-Wno-error ${CFLAGS}" CXXFLAGS="-Wno-error ${CXXFLAGS}"
# CARGO_BUILD_FLAGS is used/appended to by this Makefile
export CARGO_BUILD_FLAGS="%{__cargo_common_opts}"

# Verify non-rust deps and setup LDFLAGS
sh config.sh

# Build the project
# Replace bare `cargo` with the one used by %%cargo_* macros
%make_build CARGO="%{__cargo}" all %{?with_check:test}

%install
%make_install prefix="%{_prefix}"
# Remove executable bit from example/contrib scripts
find %{buildroot}%{_pkgdocdir}/ -type f -exec chmod -x '{}' +

%find_lang %{name}

%check
%if %{with check}
# TMPDIR=%%{_tmppath} ./test/test  # Have issues with permission in tpmdir
%cargo_test
%endif
# Ensure that the proper release version is detected
%{buildroot}%{_bindir}/newsboat --version|sed 1q|grep -v dirty

%files -f %{name}.lang
%license LICENSE
%doc README.md

%{_bindir}/newsboat
%{_bindir}/podboat

%{_mandir}/man1/newsboat.1*
%{_mandir}/man1/podboat.1*
%{_pkgdocdir}
%{_datadir}/icons/hicolor/scalable/apps/newsboat.svg

%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/newsboat.fish

%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_newsboat

%changelog
## START: Generated by rpmautospec
* Tue Jan 14 2025 Jan Staněk <jstanek@redhat.com> - 2.38-1
- Update to version 2.38 (rhbz#2333756)

* Thu Sep 26 2024 Jan Staněk <jstanek@redhat.com> - 2.37-1
- Update to version 2.37 (rhbz#2314189)

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.36-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Mon Jun 24 2024 Jan Staněk <jstanek@redhat.com> - 2.36-1
- Update to version 2.36 (rhbz#2293808)

* Tue Mar 26 2024 Jan Staněk <jstanek@redhat.com> - 2.35-1
- Update to version 2.35 (rhbz#2271374)

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.34-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.34-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Jan 09 2024 Jan Staněk <jstanek@redhat.com> - 2.34-1
- Update to version 2.34 (rhbz#2255883)

* Mon Sep 25 2023 Jan Staněk <jstanek@redhat.com> - 2.33-1
- Update to version 2.33

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.32-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jun 27 2023 Jan Staněk <jstanek@redhat.com> - 2.32-1
- Update to version 2.32 (rhbz#2217718)

* Tue Mar 28 2023 Jan Staněk <jstanek@redhat.com> - 2.31-1
- Update to version 2.31
- Adjust BR generator for updated rust tooling (cargo-inspector →
  cargo2rpm)

* Wed Feb 01 2023 Jan Staněk <jstanek@redhat.com> - 2.30.1-3
- deps: use lexopt 0.3.0

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.30.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Jan 04 2023 Jan Staněk <jstanek@redhat.com> - 2.30.1-1
- Update to version 2.30.1

* Mon Sep 26 2022 Jan Staněk <jstanek@redhat.com> - 2.29-1
- Update to version 2.29

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.28-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 27 2022 Jan Staněk <jstanek@redhat.com> - 2.28-1
- Update to version 2.28

* Thu May 12 2022 Jan Staněk <jstanek@redhat.com> - 2.27-2
- fix and check for the proper --version string

* Thu May 05 2022 Jan Staněk <jstanek@redhat.com> - 2.27-1
- update to version 2.27

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.25-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Sep 21 2021 Jan Staněk <jstanek@redhat.com> - 2.25-1
- Upgrade to version 2.25

* Mon Aug 09 2021 Jan Staněk <jstanek@redhat.com> - 2.24-1
- Upgrade to version 2.24

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.23-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sat Jul 10 2021 Björn Esser <besser82@fedoraproject.org> - 2.23-3
- Rebuild for versioned symbols in json-c

* Mon Apr 12 2021 Jan Staněk <jstanek@redhat.com> - 2.23-2
- Do not use git for patch application
  It messes up the version number reporting in the app.

* Mon Mar 22 2021 Jan Staněk <jstanek@redhat.com> - 2.23-1
- Upgrade to version 2.23

* Mon Feb 22 2021 Jan Staněk <jstanek@redhat.com> - 2.22.1-1
- Upgrade to version 2.22.1
- Switch to generate_buildrequires for rust dependencies

* Tue Feb 02 2021 Jan Staněk <jstanek@redhat.com> - 2.21-4
- Fix clap dependency constraints

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.21-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Dec 28 13:26:17 CET 2020 Igor Raits <ignatenkobrain@fedoraproject.org> - 2.21-2
- Rebuild

* Tue Oct 20 2020 Jan Staněk <jstanek@redhat.com> - 2.21-1
- Upgrade to version 2.21

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.20.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jun 25 2020 Jan Staněk <jstanek@redhat.com> - 2.20.1-1
- Upgrade to version 2.20.1

* Mon Jun 22 2020 Jan Staněk <jstanek@redhat.com> - 2.20-1
- Upgrade to version 2.20, remove upstreamed patches
- Enable source GPG signature verification

* Tue Apr 21 2020 Björn Esser <besser82@fedoraproject.org> - 2.19-3
- Rebuild (json-c)

* Mon Apr 13 2020 Björn Esser <besser82@fedoraproject.org> - 2.19-2
- Add support for upcoming json-c 0.14.0

* Mon Mar 23 2020 Jan Staněk <jstanek@redhat.com> - 2.19-1
- Upgrade to version 2.19

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.17.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 03 2019 Jan Staněk <jstanek@redhat.com> - 2.17.1-1
- Upgrade to version 2.17.1

* Mon Sep 23 2019 Jan Staněk <jstanek@redhat.com> - 2.17-1
- Upgrade to version 2.17

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.16.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Jul 22 2019 Jan Staněk <jstanek@redhat.com> - 2.16.1-2
- Import upstream fix for evaluated commands in configuration comments

* Thu Jun 27 2019 Jan Staněk <jstanek@redhat.com> - 2.16.1-1
- Upgrade to version 2.16.1
- Add %%check section

* Mon Mar 25 2019 Jan Staněk <jstanek@redhat.com> - 2.15-1
- Upgrade to version 2.15

* Mon Feb 18 2019 Jan Staněk <jstanek@redhat.com> - 2.14.1-1
- Upgrade to version 2.14.1

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.12-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 25 2018 Lee Keitel <keitellf@fedoraproject.org> - 2.12-1
- Bumped version to 2.12

* Wed Jun 13 2018 Lee Keitel <keitellf@fedoraproject.org> - 2.11.1-1
- Initial version 2.11.1

## END: Generated by rpmautospec
